@@ -1,17 +1,18 @@
 """Base classes for the CMS admin interface."""
-
 from django.contrib import admin
-from django.contrib.auth.models import User
 from django.contrib.admin.sites import NotRegistered
+from django.contrib.auth.models import User
+from reversion.admin import VersionAdmin
+from watson.admin import SearchAdmin
+
+from cms.forms import CMSAdminPasswordChangeForm
+from cms.models.base import PageBaseSearchAdapter, SearchMetaBaseSearchAdapter
 
 try:
     from usertools.admin import UserAdmin
 except ImportError:
-    from django.contrib.auth.admin import UserAdmin
+    from django.contrib.auth.admin import UserAdmin  # pylint: disable=ungrouped-imports
 
-from cms import externals
-from cms.models.base import SearchMetaBaseSearchAdapter, PageBaseSearchAdapter
-from cms.forms import CMSAdminPasswordChangeForm
 
 
 class PublishedBaseAdmin(admin.ModelAdmin):
@@ -49,7 +50,7 @@ class OnlineBaseAdmin(PublishedBaseAdmin):
     unpublish_selected.short_description = "Take selected %(verbose_name_plural)s offline"
 
 
-class SearchMetaBaseAdmin(OnlineBaseAdmin):
+class SearchMetaBaseAdmin(OnlineBaseAdmin, VersionAdmin, SearchAdmin):
 
     """Base admin class for SearchMetaBase models."""
 
@@ -62,27 +63,17 @@ class SearchMetaBaseAdmin(OnlineBaseAdmin):
         "classes": ("collapse",),
     })
 
-    OPENGRAPH_FIELDS = ("Open graph", {
+    OPENGRAPH_FIELDS = ("Open Graph", {
         "fields": ("og_title", "og_description", "og_image"),
         "classes": ("collapse",)
     })
 
-    OPENGRAPH_TWITTER_FIELDS = ("Open graph twitter", {
+    OPENGRAPH_TWITTER_FIELDS = ("Twitter card", {
         "fields": ("twitter_card", "twitter_title", "twitter_description", "twitter_image"),
         "classes": ("collapse",)
     })
 
 
-if externals.reversion:
-    class SearchMetaBaseAdmin(SearchMetaBaseAdmin, externals.reversion["admin.VersionMetaAdmin"]):
-        list_display = SearchMetaBaseAdmin.list_display + ("get_date_modified",)
-
-
-if externals.watson:
-    class SearchMetaBaseAdmin(SearchMetaBaseAdmin, externals.watson["admin.SearchAdmin"]):
-        pass
-
-
 class PageBaseAdmin(SearchMetaBaseAdmin):
 
     """Base admin class for PageBase models."""
