@@ -1,30 +1,32 @@
 """Admin settings for the static media management application."""
+from __future__ import unicode_literals
 
+import json
 import os
 from functools import partial
 
+import requests
+from django.conf.urls import url
+from django.contrib import admin, messages
+from django.contrib.admin.views.main import IS_POPUP_VAR
+from django.contrib.staticfiles.templatetags.staticfiles import static
 from django.core.files import File as DjangoFile
 from django.core.files.temp import NamedTemporaryFile
 from django.core.paginator import Paginator
-from django.conf.urls import patterns, url
-from django.contrib import admin, messages
-from django.contrib.admin.views.main import IS_POPUP_VAR
-from django.contrib.staticfiles.storage import staticfiles_storage
-from django.http import HttpResponse, HttpResponseForbidden, HttpResponseNotAllowed, Http404
-from django.shortcuts import render, get_object_or_404
+from django.http import (Http404, HttpResponse, HttpResponseForbidden,
+                         HttpResponseNotAllowed)
+from django.shortcuts import get_object_or_404, render
 from django.template.defaultfilters import filesizeformat
 from django.utils.text import Truncator
-
+from reversion.admin import VersionAdmin
 from sorl.thumbnail import get_thumbnail
-from cms import permalinks, externals
-from cms.apps.media.models import Label, File, Video
+from watson.admin import SearchAdmin
 
-import requests
-import json
+from cms import permalinks
+from cms.apps.media.models import File, Label, Video
 
 
 class LabelAdmin(admin.ModelAdmin):
-
     """Admin settings for Label models."""
 
     list_display = ("name",)
@@ -36,7 +38,6 @@ admin.site.register(Label, LabelAdmin)
 
 
 class VideoAdmin(admin.ModelAdmin):
-
     def to_field_allowed(self, request, to_field):
         """
         This is a workaround for issue #552 which will raise a security
@@ -52,17 +53,17 @@ class VideoAdmin(admin.ModelAdmin):
 
         return super(VideoAdmin, self).to_field_allowed(request, to_field)
 
+
 admin.site.register(Video, VideoAdmin)
 
-
 # Different types of file.
-AUDIO_FILE_ICON = "media/img/audio-x-generic.png"
-DOCUMENT_FILE_ICON = "media/img/x-office-document.png"
-SPREADSHEET_FILE_ICON = "media/img/x-office-spreadsheet.png"
-TEXT_FILE_ICON = "media/img/text-x-generic.png"
-IMAGE_FILE_ICON = "media/img/image-x-generic.png"
-MOVIE_FILE_ICON = "media/img/video-x-generic.png"
-UNKNOWN_FILE_ICON = "media/img/text-x-generic-template.png"
+AUDIO_FILE_ICON = static("media/img/audio-x-generic.png")
+DOCUMENT_FILE_ICON = static("media/img/x-office-document.png")
+SPREADSHEET_FILE_ICON = static("media/img/x-office-spreadsheet.png")
+TEXT_FILE_ICON = static("media/img/text-x-generic.png")
+IMAGE_FILE_ICON = static("media/img/image-x-generic.png")
+MOVIE_FILE_ICON = static("media/img/video-x-generic.png")
+UNKNOWN_FILE_ICON = static("media/img/text-x-generic-template.png")
 
 # Different types of recognised file extensions.
 FILE_ICONS = {
@@ -88,28 +89,39 @@ FILE_ICONS = {
 }
 
 
-class FileAdminBase(admin.ModelAdmin):
-
+class FileAdmin(VersionAdmin, SearchAdmin):
     """Admin settings for File models."""
 
-    fieldsets = (
+    change_list_template = 'admin/media/file/change_list.html'
+    fieldsets = [
         (None, {
-            "fields": ("title", "file",),
-        },),
-        ("Media management", {
-            "fields": ("attribution", "copyright", "labels",),
-        },),
-    )
+            'fields': ["title", "file"],
+        }),
+        ('Media management', {
+            'fields': ['attribution', 'copyright', 'alt_text', 'labels'],
+        }),
+    ]
+    filter_horizontal = ['labels']
+    list_display = ['get_number', 'get_preview', 'get_title', 'get_alt_text', 'get_size']
+    list_display_links = list_display
+    list_filter = ['labels']
+    search_fields = ['title']
+    ordering = ['pk']
 
-    list_filter = ("labels",)
 
-    search_fields = ("title",)
+    def get_number(self, obj):
+        return obj.pk
 
-    list_display = ("get_preview", "get_title", "get_size",)
+    get_number.admin_order_field = 'pk'
+    get_number.short_description = "number"
 
-    change_list_template = "admin/media/file/change_list.html"
+    def get_alt_text(self, obj):
+        if not obj.alt_text:
+            return ''
 
-    filter_horizontal = ("labels",)
+        return obj.alt_text
+
+    get_alt_text.short_description = "Alt text"
 
     def to_field_allowed(self, request, to_field):
         """
@@ -124,19 +136,19 @@ class FileAdminBase(admin.ModelAdmin):
         if to_field == 'id':
             return True
 
-        return super(FileAdminBase, self).to_field_allowed(request, to_field)
+        return super(FileAdmin, self).to_field_allowed(request, to_field)
 
     # Custom actions.
 
     def add_label_action(self, request, queryset, label):
         """Adds the label on the given queryset."""
-        for file in queryset:
-            file.labels.add(label)
+        for obj in queryset:
+            obj.labels.add(label)
 
     def remove_label_action(self, request, queryset, label):
         """Removes the label on the given queryset."""
-        for file in queryset:
-            file.labels.remove(label)
+        for obj in queryset:
+            obj.labels.remove(label)
 
     def get_actions(self, request):
         """Generates the actions for assigning categories."""
@@ -144,7 +156,7 @@ class FileAdminBase(admin.ModelAdmin):
             return []
         opts = self.model._meta
         verbose_name_plural = opts.verbose_name_plural
-        actions = super(FileAdminBase, self).get_actions(request)
+        actions = super(FileAdmin, self).get_actions(request)
         # Add the dynamic labels.
         for label in Label.objects.all():
             # Add action.
@@ -166,6 +178,7 @@ class FileAdminBase(admin.ModelAdmin):
             return filesizeformat(obj.file.size)
         except OSError:
             return "0 bytes"
+
     get_size.short_description = "size"
 
     def get_preview(self, obj):
@@ -178,7 +191,11 @@ class FileAdminBase(admin.ModelAdmin):
             try:
                 thumbnail = get_thumbnail(obj.file, '100x66', quality=99)
             except IOError:
-                pass
+                return '<img cms:permalink="{}" src="{}" width="66" height="66" alt="" title="{}"/>'.format(
+                    permalink,
+                    icon,
+                    obj.title
+                )
             else:
                 try:
                     return '<img cms:permalink="{}" src="{}" width="{}" height="{}" alt="" title="{}"/>'.format(
@@ -189,55 +206,60 @@ class FileAdminBase(admin.ModelAdmin):
                         obj.title
                     )
                 except TypeError:
-                    pass
-        else:
-            icon = staticfiles_storage.url(icon)
+                    return '<img cms:permalink="{}" src="{}" width="66" height="66" alt="" title="{}"/>'.format(
+                        permalink,
+                        icon,
+                        obj.title
+                    )
 
         return '<img cms:permalink="{}" src="{}" width="66" height="66" alt="" title="{}"/>'.format(
             permalink,
             icon,
             obj.title
         )
+
     get_preview.short_description = "preview"
     get_preview.allow_tags = True
 
     def get_title(self, obj):
         """Returns a truncated title of the object."""
         return Truncator(obj.title).words(8)
+    get_title.admin_order_field = 'title'
     get_title.short_description = "title"
 
     # Custom view logic.
 
-    def response_add(self, request, obj, *args, **kwargs):
+    def response_add(self, request, obj, post_url_continue=None):
         """Returns the response for a successful add action."""
-        if "_redactor" in request.GET:
+        if "_tinymce" in request.GET:
             context = {"permalink": permalinks.create(obj),
                        "title": obj.title}
             return render(request, "admin/media/file/filebrowser_add_success.html", context)
-        return super(FileAdminBase, self).response_add(request, obj, *args, **kwargs)
+        return super(FileAdmin, self).response_add(request, obj, post_url_continue=post_url_continue)
 
     def changelist_view(self, request, extra_context=None):
         """Renders the change list."""
         context = {
-            "changelist_template_parent": externals.reversion and "reversion/change_list.html" or "admin/change_list.html",
+            "changelist_template_parent": "reversion/change_list.html",
         }
         if extra_context:
             context.update(extra_context)
-        return super(FileAdminBase, self).changelist_view(request, context)
+        return super(FileAdmin, self).changelist_view(request, context)
 
     # Create a URL route and a view for saving the Adobe SDK callback URL.
     def get_urls(self):
-        urls = super(FileAdminBase, self).get_urls()
+        urls = super(FileAdmin, self).get_urls()
 
-        new_urls = patterns(
-            '',
+        new_urls = [
             url(r'^(?P<object_id>\d+)/remote/$', self.remote_view, name="media_file_remote"),
 
-            url(r'^redactor/upload/(?P<file_type>image|file)/$', self.redactor_upload, name="media_file_redactor_upload"),
+            url(r'^redactor/upload/(?P<file_type>image|file)/$', self.redactor_upload,
+                name="media_file_redactor_upload"),
 
             url(r'^redactor/(?P<file_type>images|files)/$', self.redactor_data, name="media_file_redactor_data"),
-            url(r'^redactor/(?P<file_type>images|files)/(?P<page>\d+)/$', self.redactor_data, name="media_file_redactor_data"),
-        )
+            url(r'^redactor/(?P<file_type>images|files)/(?P<page>\d+)/$', self.redactor_data,
+                name="media_file_redactor_data"),
+        ]
 
         return new_urls + urls
 
@@ -248,18 +270,18 @@ class FileAdminBase(admin.ModelAdmin):
         if request.method != 'POST':
             return HttpResponseNotAllowed(['POST'])
 
-        url = request.POST.get('url', None)
+        image_url = request.POST.get('url', None)
 
-        if not url:
+        if not image_url:
             raise Http404("No URL supplied.")
 
         # Pull down the remote image and save it as a temporary file.
         img_temp = NamedTemporaryFile()
-        img_temp.write(requests.get(url).content)
+        img_temp.write(requests.get(image_url).content)
         img_temp.flush()
 
         obj = get_object_or_404(File, pk=object_id)
-        obj.file.save(url.split('/')[-1], DjangoFile(img_temp))
+        obj.file.save(image_url.split('/')[-1], DjangoFile(img_temp))
 
         messages.success(request, 'The file "{}" was changed successfully. You may edit it again below.'.format(
             obj.__str__()
@@ -288,7 +310,7 @@ class FileAdminBase(admin.ModelAdmin):
         # Create files usable by the CMS
         json_data = {
             'page': page,
-            'pages': paginator.page_range,
+            'pages': list(paginator.page_range),
         }
 
         if file_type == 'files':
@@ -298,7 +320,8 @@ class FileAdminBase(admin.ModelAdmin):
             ]
         elif file_type == 'images':
             json_data['objects'] = [
-                {'title': file_object.title, 'url': permalinks.create(file_object), 'thumbnail': get_thumbnail(file_object.file, '100x75', crop="center", quality=99).url}
+                {'title': file_object.title, 'url': permalinks.create(file_object),
+                 'thumbnail': get_thumbnail(file_object.file, '100x75', crop="center", quality=99).url}
                 for file_object in paginator.page(page)
             ]
 
@@ -320,7 +343,6 @@ class FileAdminBase(admin.ModelAdmin):
         ]
 
         try:
-
             if file_type == 'image':
                 if request.FILES.getlist('file')[0].content_type not in image_content_types:
                     raise Exception()
@@ -335,28 +357,12 @@ class FileAdminBase(admin.ModelAdmin):
                 return HttpResponse(json.dumps({
                     'filelink': permalinks.create(new_file)
                 }))
-            else:
-                return HttpResponse(json.dumps({
-                    'filelink': permalinks.create(new_file),
-                    'filename': request.FILES.getlist('file')[0].name,
-                }))
-
+            return HttpResponse(json.dumps({
+                'filelink': permalinks.create(new_file),
+                'filename': request.FILES.getlist('file')[0].name,
+            }))
         except:
             return HttpResponse('')
 
 
-# Renaming needed to allow inheritance to take place in this class without infinite recursion.
-FileAdmin = FileAdminBase
-
-
-if externals.reversion:
-    class FileAdmin(FileAdmin, externals.reversion["admin.VersionMetaAdmin"]):
-        list_display = FileAdmin.list_display + ("get_date_modified",)
-
-
-if externals.watson:
-    class FileAdmin(FileAdmin, externals.watson["admin.SearchAdmin"]):
-        pass
-
-
 admin.site.register(File, FileAdmin)
