@@ -16,13 +16,12 @@ class Migration(migrations.Migration):
             name='File',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
-                ('title', models.CharField(help_text=b'The title will be used as the default rollover text when this media is embedded in a web page.', max_length=200)),
-                ('file', models.FileField(max_length=250, upload_to=b'uploads/files')),
+                ('title', models.CharField(help_text='The title will be used as the default rollover text when this media is embedded in a web page.', max_length=200)),
+                ('file', models.FileField(max_length=250, upload_to='uploads/files')),
             ],
             options={
                 'ordering': ('title',),
             },
-            bases=(models.Model,),
         ),
         migrations.CreateModel(
             name='Label',
@@ -33,27 +32,24 @@ class Migration(migrations.Migration):
             options={
                 'ordering': ('name',),
             },
-            bases=(models.Model,),
         ),
         migrations.CreateModel(
             name='Video',
             fields=[
                 ('id', models.AutoField(verbose_name='ID', serialize=False, auto_created=True, primary_key=True)),
                 ('title', models.CharField(max_length=200)),
-                ('high_resolution_mp4', cms.apps.media.models.VideoFileRefField(related_name='+', on_delete=django.db.models.deletion.PROTECT, verbose_name=b'high resolution MP4', blank=True, to='media.File', null=True)),
+                ('high_resolution_mp4', cms.apps.media.models.VideoFileRefField(related_name='+', on_delete=django.db.models.deletion.PROTECT, verbose_name='high resolution MP4', blank=True, to='media.File', null=True)),
                 ('image', cms.apps.media.models.ImageRefField(related_name='+', on_delete=django.db.models.deletion.PROTECT, blank=True, to='media.File', null=True)),
-                ('low_resolution_mp4', cms.apps.media.models.VideoFileRefField(related_name='+', on_delete=django.db.models.deletion.PROTECT, verbose_name=b'low resolution MP4', blank=True, to='media.File', null=True)),
-                ('webm', cms.apps.media.models.VideoFileRefField(related_name='+', on_delete=django.db.models.deletion.PROTECT, verbose_name=b'WebM', blank=True, to='media.File', null=True)),
+                ('low_resolution_mp4', cms.apps.media.models.VideoFileRefField(related_name='+', on_delete=django.db.models.deletion.PROTECT, verbose_name='low resolution MP4', blank=True, to='media.File', null=True)),
+                ('webm', cms.apps.media.models.VideoFileRefField(related_name='+', on_delete=django.db.models.deletion.PROTECT, verbose_name='WebM', blank=True, to='media.File', null=True)),
             ],
             options={
                 'ordering': ('title',),
             },
-            bases=(models.Model,),
         ),
         migrations.AddField(
             model_name='file',
             name='labels',
-            field=models.ManyToManyField(help_text=b'Labels are used to help organise your media. They are not visible to users on your website.', to='media.Label', blank=True),
-            preserve_default=True,
+            field=models.ManyToManyField(help_text='Labels are used to help organise your media. They are not visible to users on your website.', to='media.Label', blank=True),
         ),
     ]
