@@ -6,10 +6,10 @@ from django.conf import settings
 from django.core import urlresolvers
 from django.core.handlers.base import BaseHandler
 from django.http import Http404
-from django.views.debug import technical_404_response
 from django.shortcuts import redirect
-from django.utils.functional import cached_property
 from django.template.response import SimpleTemplateResponse
+from django.utils.functional import cached_property
+from django.views.debug import technical_404_response
 
 from cms.apps.pages.models import Page
 
@@ -160,7 +160,7 @@ class PageMiddleware(object):
                     except urlresolvers.Resolver404:
                         pass
                     else:
-                        return redirect(script_name + new_path_info)
+                        return redirect(script_name + new_path_info, permanent=True)
                 return response
             response = callback(request, *callback_args, **callback_kwargs)
             # Validate the response.
