@@ -2,17 +2,18 @@
 from __future__ import unicode_literals
 
 from django.apps import apps
-
 from django.contrib.contenttypes.models import ContentType
 from django.core import urlresolvers
-from django.db import models, connection, transaction
-from django.db.models import Q, F
+from django.db import connection, models, transaction
+from django.db.models import F, Q
+from django.utils import timezone
 from django.utils.encoding import force_text, python_2_unicode_compatible
 from django.utils.functional import cached_property
-from django.utils import timezone
+from historylinks import shortcuts as historylinks
+from reversion.models import Version
 
-from cms import sitemaps, externals
-from cms.models import PageBase, OnlineBaseManager, PageBaseSearchAdapter
+from cms import sitemaps
+from cms.models import OnlineBaseManager, PageBase, PageBaseSearchAdapter
 from cms.models.managers import publication_manager
 
 
@@ -23,7 +24,7 @@ class PageManager(OnlineBaseManager):
     def select_published(self, queryset, page_alias=None):
         """Selects only published pages."""
         queryset = super(PageManager, self).select_published(queryset)
-        now = timezone.now()
+        now = timezone.now().replace(second=0, microsecond=0)
         # Perform local filtering.
         queryset = queryset.filter(
             Q(publication_date=None) | Q(publication_date__lte=now))
@@ -203,12 +204,11 @@ class Page(PageBase):
             self.content_type_id
         ).model_class().urlconf
 
-        return self.get_absolute_url() + urlresolvers.reverse(
+        return self.get_absolute_url().rstrip('/') + urlresolvers.reverse(
             view_func,
             args=args,
             kwargs=kwargs,
             urlconf=urlconf,
-            prefix=""
         )
 
     # Standard model methods.
@@ -260,74 +260,78 @@ class Page(PageBase):
         """Saves the page."""
 
         if self.is_content_object is False:
+            with connection.cursor() as cursor:
+                cursor.execute('LOCK TABLE {} IN ROW SHARE MODE'.format(Page._meta.db_table))
 
-            # Lock entire table.
-            existing_pages = dict(
-                (page["id"], page)
-                for page
-                in Page.objects.filter(
-                    is_content_object=False
-                ).select_for_update().values(
-                    "id",
-                    "parent_id",
-                    "left",
-                    "right"
+                # Lock entire table.
+                existing_pages = dict(
+                    (page["id"], page)
+                    for page
+                    in Page.objects.filter(
+                        is_content_object=False
+                    ).select_for_update().values(
+                        "id",
+                        "parent_id",
+                        "left",
+                        "right"
+                    )
                 )
-            )
 
-            if self.left is None or self.right is None:
-                # This page is being inserted.
-                if existing_pages:
-                    parent_right = existing_pages[self.parent_id]["right"]
-                    # Set the model left and right.
-                    self.left = parent_right
-                    self.right = self.left + 1
-                    # Update the whole tree structure.
-                    self._insert_branch()
+                if self.left is None or self.right is None:
+                    # This page is being inserted.
+                    if existing_pages:
+                        parent_right = existing_pages[self.parent_id]["right"]
+                        # Set the model left and right.
+                        self.left = parent_right
+                        self.right = self.left + 1
+                        # Update the whole tree structure.
+                        self._insert_branch()
+                    else:
+                        # This is the first page to be created, ever!
+                        self.left = 1
+                        self.right = 2
                 else:
-                    # This is the first page to be created, ever!
-                    self.left = 1
-                    self.right = 2
-            else:
-                # This is an update.
-                if self.id not in existing_pages:
-                    old_parent_id = -1
-                else:
-                    old_parent_id = existing_pages[self.id]["parent_id"]
+                    # This is an update.
+                    if self.id not in existing_pages:
+                        old_parent_id = -1
+                    else:
+                        old_parent_id = existing_pages[self.id]["parent_id"]
 
-                if old_parent_id != self.parent_id:
-                    # The page has moved.
-                    branch_width = self.right - self.left + 1
-                    # Disconnect child branch.
-                    if branch_width > 2:
-                        Page.objects.filter(
-                            left__gt=self.left,
-                            right__lt=self.right
-                        ).update(
-                            left=F("left") * -1,
-                            right=F("right") * -1,
-                        )
-                    self._excise_branch()
-                    # Store old left and right values.
-                    old_left = self.left
-                    old_right = self.right
-                    # Put self into the tree.
-                    parent_right = existing_pages[self.parent_id]["right"]
-                    if parent_right > self.right:
-                        parent_right -= self._branch_width
-                    self.left = parent_right
-                    self.right = self.left + branch_width - 1
-                    self._insert_branch()
-                    # Put all children back into the tree.
-                    if branch_width > 2:
-                        child_offset = self.left - old_left
-                        Page.objects.filter(
-                            left__lt=-old_left,
-                            right__gt=-old_right
-                        ).update(
-                            left=(F("left") - child_offset) * -1,
-                            right=(F("right") - child_offset) * -1,
-                        )
+                    if old_parent_id != self.parent_id:
+                        # The page has moved.
+                        branch_width = self.right - self.left + 1
+                        # Disconnect child branch.
+                        if branch_width > 2:
+                            Page.objects.filter(
+                                left__gt=self.left,
+                                right__lt=self.right
+                            ).update(
+                                left=F("left") * -1,
+                                right=F("right") * -1,
+                            )
+                        self._excise_branch()
+                        # Store old left and right values.
+                        old_left = self.left
+                        old_right = self.right
+                        # Put self into the tree.
+                        if self.parent_id:
+                            parent_right = existing_pages[self.parent_id]["right"]
+                            if parent_right > self.right:
+                                parent_right -= self._branch_width
+                            self.left = parent_right
+                            self.right = self.left + branch_width - 1
+                            self._insert_branch()
+
+                            # Put all children back into the tree.
+                            if branch_width > 2:
+                                child_offset = self.left - old_left
+                                Page.objects.filter(
+                                    left__lt=-old_left,
+                                    right__gt=-old_right
+                                ).update(
+                                    left=(F("left") - child_offset) * -1,
+                                    right=(F("right") - child_offset) * -1,
+                                )
 
         # Now actually save it!
         super(Page, self).save(*args, **kwargs)
@@ -347,12 +351,23 @@ class Page(PageBase):
         # Update the entire tree.
         self._excise_branch()
 
+    def last_modified(self):
+        versions = Version.objects.get_for_object(self)
+        if versions.count() > 0:
+            latest_version = versions[:1][0]
+            return "{} by {}".format(
+                latest_version.revision.date_created.strftime("%Y-%m-%d %H:%M:%S"),
+                latest_version.revision.user
+            )
+        return "-"
+
+
     class Meta:
         unique_together = (("parent", "slug", "country_group"),)
         ordering = ("left",)
 
 
-externals.historylinks("register", Page)
+historylinks.register(Page)
 
 
 class PageSitemap(sitemaps.PageBaseSitemap):
@@ -402,9 +417,6 @@ class PageSearchAdapter(PageBaseSearchAdapter):
         return qs
 
 
-externals.watson("register", Page, adapter_cls=PageSearchAdapter)
-
-
 # Base content class.
 
 def get_registered_content():
@@ -461,7 +473,7 @@ class ContentBase(models.Model):
 
     def __str__(self):
         """Returns a unicode representation."""
-        return str(self.page)
+        return self.page.title
 
     class Meta:
         abstract = True
