@@ -1,25 +1,30 @@
+import json
+import os
+import sys
 from copy import deepcopy
+
+import reversion
 from django.conf import settings
 from django.contrib import admin
 from django.contrib.admin.sites import AdminSite
-from django.contrib.admin.widgets import FilteredSelectMultiple, RelatedFieldWidgetWrapper
+from django.contrib.admin.widgets import (FilteredSelectMultiple,
+                                          RelatedFieldWidgetWrapper)
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.messages.storage.fallback import FallbackStorage
 from django.core.exceptions import PermissionDenied
 from django.db import models
 from django.http import Http404, HttpResponseRedirect
 from django.http.request import QueryDict
-from django.test import TestCase, RequestFactory
+from django.test import RequestFactory, TestCase
 from django.utils import six
+from django.utils.text import slugify
+from reversion.models import Version
+from watson import search
 
-from ..admin import PageAdmin, PAGE_FROM_KEY, PAGE_FROM_SITEMAP_VALUE, PAGE_TYPE_PARAMETER
-from ..models import get_registered_content, ContentBase, Page, CountryGroup, \
-    Country
-from .... import externals
-
-import json
-import os
-import sys
+from ..admin import (PAGE_FROM_KEY, PAGE_FROM_SITEMAP_VALUE,
+                     PAGE_TYPE_PARAMETER, PageAdmin, PageContentTypeFilter)
+from ..models import (ContentBase, Country, CountryGroup, Page,
+                      get_registered_content)
 
 
 # Test models
@@ -81,11 +86,13 @@ def get_inline_instances_1_4_x(self, request):
 
 class TestPageAdmin(TestCase):
 
+    maxDiff = None
+
     def setUp(self):
         self.site = AdminSite()
         self.page_admin = PageAdmin(Page, self.site)
 
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(PageContent)
 
             self.homepage = Page.objects.create(
@@ -106,7 +113,9 @@ class TestPageAdmin(TestCase):
         request.GET = QueryDict('', mutable=True)
         request.POST = QueryDict('', mutable=True)
         request.COOKIES = {}
-        request.META = {}
+        request.META = {
+            'SCRIPT_NAME': ''
+        }
         request.method = method
         request.path = '/'
         request.resolver_match = False
@@ -116,6 +125,19 @@ class TestPageAdmin(TestCase):
 
         return request
 
+    def _make_page(self, title, content_type):
+            ''' Little helper to create a page whose parent is the homepage. '''
+            content_page = Page.objects.create(
+                title=title,
+                slug=slugify(title),
+                parent=self.homepage,
+                content_type=content_type,
+            )
+
+            content_type.model_class().objects.create(
+                page=content_page,
+            )
+
     def test_pageadmin_get_object(self):
         factory = RequestFactory()
         request = factory.get('/')
@@ -186,13 +208,13 @@ class TestPageAdmin(TestCase):
         )
 
         # Create an initial revision.
-        with externals.reversion.create_revision():
+        with reversion.create_revision():
             self.homepage.content.save()
 
-        versions = externals.reversion.get_for_object(self.homepage.content)
+        versions = Version.objects.get_for_object(self.homepage.content)
 
         data = self.page_admin.get_revision_form_data(request, self.homepage, versions[0])
-        self.assertDictEqual(data, {'page': self.homepage.pk})
+        self.assertDictEqual(data, {'page_id': self.homepage.pk})
 
     def test_pageadmin_get_page_content_cls(self):
         request = self._build_request(
@@ -208,9 +230,6 @@ class TestPageAdmin(TestCase):
 
         self.assertEqual(self.page_admin.get_page_content_cls(request2, self.homepage), PageContent)
 
-        with self.assertRaises(AttributeError):
-            self.page_admin.get_page_content_cls(request2, self.homepage.content)
-
     def test_pageadmin_get_fieldsets(self):
         request = self._build_request(
             page_type=ContentType.objects.get_for_model(PageContent).pk
@@ -219,7 +238,7 @@ class TestPageAdmin(TestCase):
             page_type=ContentType.objects.get_for_model(PageContentWithFields).pk
         )
 
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(PageContentWithFields)
 
             self.content_page = Page.objects.create(
@@ -252,11 +271,11 @@ class TestPageAdmin(TestCase):
                 'fields': ('browser_title', 'meta_description', 'sitemap_priority', 'sitemap_changefreq', 'robots_index', 'robots_follow', 'robots_archive'),
                 'classes': ('collapse',)
             }),
-            ("Open graph", {
+            ("Open Graph", {
                 "fields": ("og_title", "og_description", "og_image"),
                 "classes": ("collapse",)
             }),
-            ("Open graph twitter", {
+            ("Twitter card", {
                 "fields": ("twitter_card", "twitter_title", "twitter_description", "twitter_image"),
                 "classes": ("collapse",)
             })
@@ -284,11 +303,11 @@ class TestPageAdmin(TestCase):
                 'fields': ('browser_title', 'meta_description', 'sitemap_priority', 'sitemap_changefreq', 'robots_index', 'robots_follow', 'robots_archive'),
                 'classes': ('collapse',)
             }),
-            ("Open graph", {
+            ("Open Graph", {
                 "fields": ("og_title", "og_description", "og_image"),
                 "classes": ("collapse",)
             }),
-            ("Open graph twitter", {
+            ("Twitter card", {
                 "fields": ("twitter_card", "twitter_title", "twitter_description", "twitter_image"),
                 "classes": ("collapse",)
             })
@@ -301,7 +320,7 @@ class TestPageAdmin(TestCase):
         self.assertListEqual(self.page_admin.get_all_children(self.homepage), [])
 
         # Add a child page.
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(PageContentWithFields)
 
             self.content_page = Page.objects.create(
@@ -343,7 +362,7 @@ class TestPageAdmin(TestCase):
         request = self._build_request()
 
         # Test a page with a content model with fields.
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(PageContentWithFields)
 
             self.content_page = Page.objects.create(
@@ -537,7 +556,7 @@ class TestPageAdmin(TestCase):
 
         NEW_MIDDLEWARE_CLASSES = [
             'cms.middleware.LocalisationMiddleware',
-        ] + settings.MIDDLEWARE_CLASSES
+        ] + list(settings.MIDDLEWARE_CLASSES)
 
         with self.settings(MIDDLEWARE_CLASSES=NEW_MIDDLEWARE_CLASSES):
             request = self._build_request()
@@ -549,10 +568,10 @@ class TestPageAdmin(TestCase):
         request = self._build_request()
 
         # Create an initial revision.
-        with externals.reversion.create_revision():
+        with reversion.create_revision():
             self.homepage.content.save()
 
-        versions = externals.reversion.get_for_object(self.homepage.content)
+        versions = Version.objects.get_for_object(self.homepage.content)
 
         response = self.page_admin.revision_view(request, str(self.homepage.pk), (versions[0].pk))
         self.assertEqual(response.status_code, 200)
@@ -625,13 +644,13 @@ class TestPageAdmin(TestCase):
         request = self._build_request()
         response = self.page_admin.sitemap_json_view(request)
 
-        sitemap = '{"createHomepageUrl": "/admin/pages/page/add/?from=sitemap", "addUrl": "/admin/pages/page/add/?from=sitemap&parent=__id__", "canAdd": true, "changeUrl": "/admin/pages/page/__id__/?from=sitemap", "entries": [{"isOnline": true, "canDelete": true, "title": "Homepage", "canChange": true, "id": ' + str(self.homepage.pk) + ', "children": []}], "deleteUrl": "/admin/pages/page/__id__/delete/?from=sitemap", "moveUrl": "/admin/pages/page/move-page/"}'
+        sitemap = '{"createHomepageUrl": "/admin/pages/page/add/?from=sitemap", "addUrl": "/admin/pages/page/add/?from=sitemap&parent=__id__", "canAdd": true, "changeUrl": "/admin/pages/page/__id__/change/?from=sitemap", "entries": [{"isOnline": true, "canDelete": true, "title": "Homepage", "canChange": true, "id": ' + str(self.homepage.pk) + ', "children": []}], "deleteUrl": "/admin/pages/page/__id__/delete/?from=sitemap", "moveUrl": "/admin/pages/page/move-page/"}'
 
         self.assertDictEqual(json.loads(response.content.decode()), json.loads(sitemap))
         self.assertEqual(response['Content-Type'], "application/json; charset=utf-8")
 
         # Add a child page.
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(PageContentWithFields)
 
             self.content_page = Page.objects.create(
@@ -647,13 +666,13 @@ class TestPageAdmin(TestCase):
 
         request.pages.homepage = Page.objects.get(slug='homepage')
         response = self.page_admin.sitemap_json_view(request)
-        sitemap = '{"createHomepageUrl": "/admin/pages/page/add/?from=sitemap", "addUrl": "/admin/pages/page/add/?from=sitemap&parent=__id__", "canAdd": true, "changeUrl": "/admin/pages/page/__id__/?from=sitemap", "entries": [{"isOnline": true, "canDelete": true, "title": "Homepage", "canChange": true, "id": ' + str(self.homepage.pk) + ', "children": [{"isOnline": true, "canDelete": true, "title": "Content page", "canChange": true, "id": ' + str(self.content_page.pk) + ', "children": []}]}], "deleteUrl": "/admin/pages/page/__id__/delete/?from=sitemap", "moveUrl": "/admin/pages/page/move-page/"}'
+        sitemap = '{"createHomepageUrl": "/admin/pages/page/add/?from=sitemap", "addUrl": "/admin/pages/page/add/?from=sitemap&parent=__id__", "canAdd": true, "changeUrl": "/admin/pages/page/__id__/change/?from=sitemap", "entries": [{"isOnline": true, "canDelete": true, "title": "Homepage", "canChange": true, "id": ' + str(self.homepage.pk) + ', "children": [{"isOnline": true, "canDelete": true, "title": "Content page", "canChange": true, "id": ' + str(self.content_page.pk) + ', "children": []}]}], "deleteUrl": "/admin/pages/page/__id__/delete/?from=sitemap", "moveUrl": "/admin/pages/page/move-page/"}'
         self.assertDictEqual(json.loads(response.content.decode()), json.loads(sitemap))
         self.assertEqual(response['Content-Type'], "application/json; charset=utf-8")
 
         request.pages.homepage = None
         response = self.page_admin.sitemap_json_view(request)
-        sitemap = '{"createHomepageUrl": "/admin/pages/page/add/?from=sitemap", "addUrl": "/admin/pages/page/add/?from=sitemap&parent=__id__", "canAdd": true, "changeUrl": "/admin/pages/page/__id__/?from=sitemap", "entries": [], "deleteUrl": "/admin/pages/page/__id__/delete/?from=sitemap", "moveUrl": "/admin/pages/page/move-page/"}'
+        sitemap = '{"createHomepageUrl": "/admin/pages/page/add/?from=sitemap", "addUrl": "/admin/pages/page/add/?from=sitemap&parent=__id__", "canAdd": true, "changeUrl": "/admin/pages/page/__id__/change/?from=sitemap", "entries": [], "deleteUrl": "/admin/pages/page/__id__/delete/?from=sitemap", "moveUrl": "/admin/pages/page/move-page/"}'
         self.assertDictEqual(json.loads(response.content.decode()), json.loads(sitemap))
         self.assertEqual(response['Content-Type'], "application/json; charset=utf-8")
 
@@ -683,7 +702,7 @@ class TestPageAdmin(TestCase):
         sys.stderr = self.orig_stderr
 
         # Add some child pages.
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(PageContent)
 
             content_page_1 = Page.objects.create(
@@ -806,7 +825,7 @@ class TestPageAdmin(TestCase):
         response = self.page_admin.duplicate_for_country_group(request, page=self.homepage.pk)
         self.assertEquals(Page.objects.filter(owner=self.homepage, is_content_object=True).count(), 1)
 
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
 
             content_type_2 = ContentType.objects.get_for_model(
                 PageContentWithFields)
@@ -835,3 +854,60 @@ class TestPageAdmin(TestCase):
             inline_page_clone = Page.objects.get(owner=inline_page, is_content_object=True)
 
             self.assertEquals(inline_page_clone.inlinemodel_set.count(), 1)
+
+    def test_pagecontenttypefilter_queryset(self):
+        # Ensures that the queryset returned by filtering is correct.
+        request = self._build_request()
+
+        # Add some pages with different content types.
+        with search.update_index():
+            content_type = ContentType.objects.get_for_model(PageContent)
+            content_type_2 = ContentType.objects.get_for_model(PageContentWithFields)
+
+            self._make_page('Food', content_type)
+            self._make_page('Barred', content_type)
+            self._make_page('Bazooka', content_type_2)
+
+        # Test with no filters. Should be the same as Page.objects.all().
+        filterer = PageContentTypeFilter(request, {}, Page, self.page_admin)
+        queryset = filterer.queryset(request, Page.objects.all())
+        self.assertEqual(queryset.count(), Page.objects.all().count())
+
+        # Test with a content type filter. It should return a subset of the
+        # pages.
+        content_type_id = ContentType.objects.get_for_model(PageContent).id
+        parameters = {'page_type': content_type_id}
+        filterer = PageContentTypeFilter(request, parameters, Page, self.page_admin)
+        queryset = filterer.queryset(request, Page.objects.all())
+        self.assertEqual(
+            queryset.count(),
+            Page.objects.filter(
+                content_type_id=content_type_id
+            ).count()
+        )
+        # The above will not be sufficient - we need to ensure that it is not
+        # the same as the unfiltered queryset, not merely that the filtered
+        # length is correct.
+        self.assertNotEqual(queryset.count(), Page.objects.all().count())
+
+    def test_pagecontenttypefilter_lookups(self):
+        # Add some pages with different content types.
+        with search.update_index():
+            content_type = ContentType.objects.get_for_model(PageContent)
+            content_type_2 = ContentType.objects.get_for_model(PageContentWithFields)
+
+            self._make_page('John', content_type)
+            self._make_page('Paul', content_type)
+            self._make_page('Ringo', content_type_2)
+        request = self._build_request()
+        filterer = PageContentTypeFilter(request, {}, Page, self.page_admin)
+        lookups = filterer.lookups(request, Page.objects.all())
+        # Make sure that something has been returned...
+        self.assertTrue(len(lookups) > 0)
+
+        # ...and that they are of the correct content type.
+        self.assertTrue(len(lookups) == len(get_registered_content()))
+
+        # Ensure that the lookup names have been ordered.
+        lookup_names = [lookup[1] for lookup in lookups]
+        self.assertEqual(lookup_names, sorted(lookup_names))
