@@ -1,22 +1,15 @@
 from django.contrib.contenttypes.models import ContentType
 from django.http import HttpResponse, HttpResponseNotFound
-from django.test import TestCase, RequestFactory
+from django.test import RequestFactory, TestCase
+from watson import search
 
-from ..middleware import RequestPageManager, PageMiddleware
-from ..models import ContentBase, Page, CountryGroup, Country
-from .... import externals
-
-
-class TestMiddlewarePage(ContentBase):
-    pass
-
-
-class TestMiddlewarePageURLs(ContentBase):
-    urlconf = 'cms.apps.pages.tests.urls'
+from ..middleware import PageMiddleware, RequestPageManager
+from ..models import Country, CountryGroup, Page
+from .models import TestMiddlewarePage, TestMiddlewarePageURLs
 
 
 def _generate_pages(self):
-    with externals.watson.context_manager("update_index")():
+    with search.update_index():
         content_type = ContentType.objects.get_for_model(TestMiddlewarePage)
 
         self.homepage = Page.objects.create(
@@ -104,6 +97,10 @@ class TestRequestPageManager(TestCase):
     def test_homepage(self):
         self.assertIsNone(self.page_manager.homepage)
 
+        _generate_pages(self)
+        page_manager = RequestPageManager(self.request)
+        self.assertTrue(page_manager.is_homepage)
+
     def test_breadcrumbs(self):
         _generate_pages(self)
 
@@ -208,7 +205,7 @@ class TestRequestPageManager(TestCase):
         )
 
         # Create an alternate version of the page with the country.
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(TestMiddlewarePage)
 
             alternate_page = Page.objects.create(
@@ -263,6 +260,7 @@ class TestPageMiddleware(TestCase):
         request = self.factory.get('/foo/')
         request.pages = RequestPageManager(request)
         processed_response = middleware.process_response(request, response)
+
         self.assertEqual(processed_response.status_code, 200)
         self.assertEqual(processed_response.template_name, (
             'pages/testmiddlewarepage.html',
@@ -276,7 +274,7 @@ class TestPageMiddleware(TestCase):
         processed_response = middleware.process_response(request, response)
 
         self.assertEqual(processed_response['Location'], '/foo/')
-        self.assertEqual(processed_response.status_code, 302)
+        self.assertEqual(processed_response.status_code, 301)
         self.assertEqual(processed_response.content, b'')
 
         request = self.factory.get('/foobar/')
@@ -284,7 +282,7 @@ class TestPageMiddleware(TestCase):
         processed_response = middleware.process_response(request, response)
         self.assertEqual(processed_response.status_code, 404)
 
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(TestMiddlewarePageURLs)
 
             self.content_url = Page.objects.create(
@@ -303,7 +301,7 @@ class TestPageMiddleware(TestCase):
         processed_response = middleware.process_response(request, HttpResponseNotFound())
         self.assertEqual(processed_response.status_code, 500)
 
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(TestMiddlewarePageURLs)
 
             self.content_url = Page.objects.create(
