@@ -1,13 +1,17 @@
 """Tests for the pages app."""
+from datetime import timedelta
 
+from django.contrib.contenttypes.models import ContentType
+from django.core.management import call_command
 from django.db import models
 from django.test import TestCase
-from django.core.management import call_command
-from django.contrib.contenttypes.models import ContentType
+from django.utils.timezone import now
+from reversion import create_revision
+from watson import search
 
-from ..models import filter_indexable_pages, ContentBase, Page, PageSearchAdapter, PageSitemap
-from .... import externals
 from ....models.managers import publication_manager
+from ..models import (ContentBase, Page, PageSearchAdapter, PageSitemap,
+                      filter_indexable_pages)
 
 
 class TestPageContent(ContentBase):
@@ -33,7 +37,7 @@ class TestPage(TestCase):
     def setUp(self):
         call_command('installwatson')
 
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(TestPageContent)
 
             self.homepage = Page.objects.create(
@@ -140,18 +144,18 @@ class TestPage(TestCase):
         self.assertEqual(self.subsubsection.content.__str__(), 'Subsubsection')
 
     def test_pagesearchadapter_get_live_queryset(self):
-        self.assertEqual(len(externals.watson.search("Homepage", models=(Page,))), 1)
+        self.assertEqual(len(search.search("Homepage", models=(Page,))), 1)
 
         with publication_manager.select_published(True):
-            self.assertEqual(len(externals.watson.search("Homepage", models=(Page,))), 1)
+            self.assertEqual(len(search.search("Homepage", models=(Page,))), 1)
 
             self.homepage.is_online = False
             self.homepage.save()
 
-            self.assertEqual(len(externals.watson.search("Homepage", models=(Page,))), 0)
+            self.assertEqual(len(search.search("Homepage", models=(Page,))), 0)
 
     def test_page_get_absolute_url(self):
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             Page.objects.all().delete()
 
             content_type = ContentType.objects.get_for_model(TestPageContent)
@@ -177,11 +181,47 @@ class TestPage(TestCase):
         self.assertEqual(new_page.cached_url, '/')
         self.assertEqual(new_page.get_absolute_url(), '/')
 
+    def test_last_modified(self):
+
+        # We have no versions
+        self.assertEquals(self.homepage.last_modified(), '-')
+
+        # Create an initial revision.
+        with create_revision():
+            self.homepage.save()
+
+        # We have reversion and a version in the db, last_modified should not be empty
+        self.assertNotEquals(self.homepage.last_modified(), '-')
+
+    def test_publication(self):
+        self.homepage.publication_date = now() + timedelta(days=10)
+        self.homepage.save()
+
+        self.section.publication_date = now() + timedelta(days=10)
+        self.section.save()
+
+        self.subsection.publication_date = now() + timedelta(days=10)
+        self.subsection.save()
+
+        self.subsubsection.publication_date = now() + timedelta(days=10)
+        self.subsubsection.save()
+
+        with publication_manager.select_published(True):
+            self.assertEqual(Page.objects.count(), 0)
+
+        with publication_manager.select_published(False):
+            self.assertEqual(Page.objects.count(), 4)
+
+        # We need to generate an exception within the published block.
+        with self.assertRaises(TypeError), \
+                publication_manager.select_published(True):
+            assert 1 / 'a'
+
 
 class TestSectionPage(TestCase):
 
     def setUp(self):
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(TestPageContentWithSections)
 
             self.homepage = Page.objects.create(
@@ -286,7 +326,7 @@ class TestPageComplex(TestCase):
                 for child in page['children']:
                     _add_page(child, page_obj)
 
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             _add_page(structure)
             self._rebuild_page_dict()
 
@@ -346,7 +386,7 @@ class TestPageComplex(TestCase):
         self.assertEqual(self.pages['Tree_3___Page_5'].right, 15)
 
     def test_page_save__create_with_sides(self):
-        with externals.watson.context_manager("update_index")():
+        with search.update_index():
             content_type = ContentType.objects.get_for_model(TestPageContent)
 
             # Create a page with a manual left and right defined.
