@@ -1,8 +1,10 @@
-from django.test import TestCase, RequestFactory
+from django.test import RequestFactory, TestCase
 
-from ..models.base import (PublishedBaseSearchAdapter as CMSPublishedBaseSearchAdapter,
-                           SearchMetaBaseSearchAdapter as CMSSearchMetaBaseSearchAdapter,
-                           PageBase, PublishedBase, SearchMetaBase)
+from ..models.base import \
+    PublishedBaseSearchAdapter as CMSPublishedBaseSearchAdapter
+from ..models.base import \
+    SearchMetaBaseSearchAdapter as CMSSearchMetaBaseSearchAdapter
+from ..models.base import PageBase, PublishedBase, SearchMetaBase
 
 
 # Test models.
@@ -59,8 +61,15 @@ class ModelsBaseTest(TestCase):
         request = factory.get('/')
         request.pages = []
 
+        class Context(dict):
+            pass
+
+        context = Context()
+        context['page_obj'] = Context()
+        context['page_obj'].has_other_pages = lambda: False
+
         obj = TestSearchMetaBaseModel.objects.create()
-        response = obj.render(request, '../templates/pagination/pagination.html')
+        response = obj.render(request, 'pagination/pagination.html', context)
 
         self.assertEqual(response.status_code, 200)
 
