@@ -39,10 +39,6 @@ class PageDetailMixin(SearchMetaDetailMixin):
 
     """Generates the context for a page detail view."""
 
-    slug_field = "url_title"
-
-    slug_url_kwarg = "url_title"
-
 
 class SearchMetaDetailView(SearchMetaDetailMixin, generic.DetailView):
 
